
var express      = require('express')
  , integrations = require('..')
  , helpers      = require('./helpers')
  , should       = require('should')
  , webhook      = new integrations.Webhooks();


var app = express().use(express.bodyParser())
  , server;


describe('Webhooks', function () {

  before(function (done) { server = app.listen(4000, done); });
  after(function(done) { server.close(done); });


  describe('.enabled()', function () {

    it('should always be enabled', function () {
      var message = helpers.identify();
      webhook.enabled(message, { channel : 'server' }).should.be.ok;
      webhook.enabled(message, { channel : 'client' }).should.be.ok;
      webhook.enabled(message, {}).should.be.ok;
    });
  });


  describe('.validate()', function () {

    it('should require a valid globalHook', function () {
      var message = {};

      should.not.exist(webhook.validate(message, {
        globalHook : 'http://www.segment.io'
      }));

      should.exist(webhook.validate(message, {}));
      should.exist(webhook.validate(message, { globalHook : true }));
      should.exist(webhook.validate(message, { globalHook : '' }));
      should.exist(webhook.validate(message, { globalHook : 'aaaa' }));
    });
  });


  /**
   * Test that our api calls forward properly
   */
  ['track', 'identify', 'alias'].forEach(testApiCall);

});


/**
 * Test an api call to make sure that it gets passed along properly
 * @param  {String} call ['identify', 'track', or 'alias']
 */
function testApiCall (call) {

  var message = helpers[call]();

  describe('.' + call + '()', function () {

    it('should succeed on an valid call', function (done) {

      var route = '/' + call + '/valid'
        , settings = { globalHook : 'http://localhost:4000' + route };

      app.post(route, function (req, res, next) {
        var json = message.json();
        json.options = json.options || json.context;
        delete json.context;

        serialized(req.body).should.eql(serialized(json));
        res.send();
      });

      webhook[call](message, settings, function (err) {
        should.not.exist(err);
        done();
      });
    });

    it('should not succeed on an error', function (done) {
      this.timeout(15000); // TODO: remove

      var route    = '/' + call + '/error'
        , settings = { globalHook : 'http://localhost:4000' + route }
        , status   = 503;

      app.post(route, function (req, res, next) {
        var json = message.json();
        json.options = json.options || json.context;
        delete json.context;
        serialized(req.body).should.eql(serialized(json));
        res.send(status);
      });

      webhook[call](message, settings, function (err) {
        should.exist(err);
        err.status.should.eql(status);
        done();
      });
    });
  });
}


function serialized (obj) {
  return JSON.parse(JSON.stringify(obj));
}